pub struct SessionLockTable { /* private fields */ }Expand description
Per-session lifecycle mutex table.
Invariants:
- At most one
close_session/promote/ recovery-adopt runs concurrently for a given session_id. - Different session_ids proceed concurrently.
- Entries are Arc-refcounted.
SessionLifecycleGuard::dropopportunistically removes the entry when this task was the last waiter; readers that observed the entry before the remove simply create a new Arc — correctness is preserved because they cannot yet hold the guard.